from itertools import product
from collections import namedtuple

import xarray as xr

from toargridding.toar_rest_client import AnalysisService
from toargridding.grids import GridDefinition
from toargridding.metadata import Metadata, TimeSample

GriddedResult = namedtuple("GriddedResult", ["dataset", "metadata"])


def get_gridded_toar_data(
    analysis_service: AnalysisService,
    grid: GridDefinition,
    time: TimeSample,
    variables: list[str],
    stats: list[str],
) -> tuple[list[xr.Dataset], list[Metadata]]:
    metadatas = [
        Metadata.construct(var, stat, time) for var, stat in product(variables, stats)
    ]

    datasets = []
    for metadata in metadatas:  # standart_name ?
        data = analysis_service.get_data(metadata)
        ds = grid.as_xarray(data)
        datasets.append(ds)

    return datasets, metadatas
