from pathlib import Path
from dataclasses import dataclass
import json

STATIC_METADATA_PATH = Path(__file__).parent / "static_metadata"
TOAR_VARIABLES_METADATA_PATH = STATIC_METADATA_PATH / "toar_variables.json"
GLOABAL_CF_ATTRIBUTES_PATH = STATIC_METADATA_PATH / "global_cf_attributes.json"


def load_global_cf_attributes():
    with open(GLOABAL_CF_ATTRIBUTES_PATH, "r") as f:
        return json.load(f)


@dataclass
class TOARVariable:
    vars = None

    name: str
    longname: str
    displayname: str
    cf_standardname: str
    units: str
    chemical_formula: str
    id: int

    @classmethod
    def load_toar_variables(cls) -> list["TOARVariable"]:
        with open(TOAR_VARIABLES_METADATA_PATH, "r") as f:
            variables = json.load(f)

        cls.vars = [TOARVariable(**var) for var in variables]

    @classmethod
    def get(cls, standart_name: str) -> "TOARVariable":
        for var in cls.vars:
            if var.standart_name == standart_name:
                return var
        else:
            raise ValueError(f"TOAR Database contains no variable {standart_name}")

    @property
    def toar_id(self):
        return self.id

    @property
    def standart_name(self):
        return self.cf_standardname

    @property
    def long_name(self):
        return self.longname


TOARVariable.load_toar_variables()
global_cf_attributes = load_global_cf_attributes()
